%define nginx_user	nginx
%define nginx_group	%{nginx_user}
%define nginx_home	%{_localstatedir}/lib/nginx
%define nginx_home_tmp	%{nginx_home}/tmp
%define nginx_logdir	%{_localstatedir}/log/nginx
%define nginx_confdir	%{_sysconfdir}/nginx
%define nginx_datadir	%{_datadir}/nginx
%define nginx_webroot	%{nginx_datadir}/html
%define real_name	nginx
%define nginx_builddir	bundle/%{real_name}-1.7.0

Name:			ngx_openresty
Version:		1.7.0.1
Release:		1%{?dist}
Summary:		Turning Nginx into a full-fledged Web App server
Group:			System Environment/Daemons

License:		BSD
URL:			http://openresty.org/
BuildRoot:		%{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires:		readline-devel pcre-devel openssl-devel perl(ExtUtils::Embed)
BuildRequires:		libxslt-devel gd-devel

Requires:		pcre openssl gd
Requires:		perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires(pre):		shadow-utils
Requires(post):		chkconfig
Requires(preun):	chkconfig initscripts
Requires(postun):	initscripts
Conflicts:		nginx nginx-stable

Source0:		http://nginx.org/download/ngx_openresty-%{version}.tar.gz
Source1:		%{real_name}.init
Source2:		%{real_name}.logrotate
Source3:		virtual.conf
Source4:		ssl.conf
Source5:		nginx-upstream-fair.zip
Source6:		upstream-fair.conf
Source7:		%{real_name}.sysconfig
Source104:		404.html

# configuration patch to match all the Fedora paths for logs, pid files
# etc.
Patch1:     nginx-config.patch

%description
OpenResty (aka. ngx_openresty) is a full-fledged web application server
by bundling the standard Nginx core, lots of 3rd-party Nginx modules,
as well as most of their external dependencies.

%prep
%setup

cd %{nginx_builddir}
%patch1 -p0

%setup -T -D -a 5

%build
# nginx does not utilize a standard configure script.  It has its own
# and the standard configure options cause the nginx configure script
# to error out.  This is is also the reason for the DESTDIR environment
# variable.  The configure script(s) have been patched (Patch1 and
# Patch2) in order to support installing into a build environment.
export DESTDIR=%{buildroot}
./configure \
    --user=%{nginx_user} \
    --group=%{nginx_group} \
    --prefix=%{nginx_datadir} \
    --sbin-path=%{_sbindir}/%{real_name} \
    --conf-path=%{nginx_confdir}/%{real_name}.conf \
    --error-log-path=%{nginx_logdir}/error.log \
    --http-log-path=%{nginx_logdir}/access.log \
    --http-client-body-temp-path=%{nginx_home_tmp}/client_body \
    --http-proxy-temp-path=%{nginx_home_tmp}/proxy \
    --http-fastcgi-temp-path=%{nginx_home_tmp}/fastcgi \
    --http-uwsgi-temp-path=%{nginx_home_tmp}/uwsgi \
    --http-scgi-temp-path=%{nginx_home_tmp}/scgi \
    --pid-path=%{_localstatedir}/run/%{real_name}.pid \
    --lock-path=%{_localstatedir}/lock/subsys/%{real_name} \
    --with-http_secure_link_module \
    --with-http_random_index_module \
    --with-http_ssl_module \
    --with-http_realip_module \
    --with-http_addition_module \
    --with-http_xslt_module \
    --with-http_image_filter_module \
    --with-http_sub_module \
    --with-http_dav_module \
    --with-http_flv_module \
    --with-http_mp4_module \
    --with-http_gzip_static_module \
    --with-http_random_index_module \
    --with-http_secure_link_module \
    --with-http_degradation_module \
    --with-http_stub_status_module \
    --with-http_perl_module \
    --with-mail \
    --with-mail_ssl_module \
    --with-ipv6 \
    --with-cc-opt="%{optflags} $(pcre-config --cflags)" \
    --with-luajit \
    --with-http_iconv_module \
    --add-module=%{_builddir}/%{name}-%{version}/nginx-upstream-fair-master
make %{?_smp_mflags}

# rename the readme for nginx-upstream-fair so it doesn't conflict with the main
# readme
mv nginx-upstream-fair-master/README nginx-upstream-fair-master/README.nginx_upstream_fair

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} INSTALLDIRS=vendor
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -type f -name perllocal.pod -exec rm -f {} \;
find %{buildroot} -type f -empty -exec rm -f {} \;
find %{buildroot} -type f -exec chmod 0644 {} \;
find %{buildroot} -type f -name '*.so' -exec chmod 0755 {} \;
chmod 0755 %{buildroot}%{_sbindir}/nginx
%{__install} -p -D -m 0755 %{SOURCE1} %{buildroot}%{_initrddir}/%{real_name}
%{__install} -p -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{real_name}
%{__install} -p -D -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/sysconfig/%{real_name}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_confdir}/conf.d
%{__install} -p -m 0644 %{SOURCE3} %{SOURCE4} %{SOURCE6} %{buildroot}%{nginx_confdir}/conf.d
%{__install} -p -d -m 0755 %{buildroot}%{nginx_home_tmp}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_logdir}
%{__install} -p -D -m 0644 %{nginx_builddir}/man/%{real_name}.8 %{buildroot}%{_mandir}/man8/%{real_name}.8
cp README.markdown README
mv %{nginx_builddir}/CHANGES %{nginx_builddir}/CHANGES.nginx
mv %{nginx_builddir}/README %{nginx_builddir}/README.nginx
mv %{buildroot}%{nginx_datadir}/nginx/html %{buildroot}%{nginx_webroot}
%{__install} -p -m 0644 %{SOURCE104} %{buildroot}%{nginx_webroot}

# drop development files
rm -rf %{buildroot}%{nginx_datadir}/nginx
rm -rf %{buildroot}%{nginx_datadir}/luajit/include
rm -rf %{buildroot}%{nginx_datadir}/luajit/lib/{*.a,lua,pkgconfig}
rm -rf %{buildroot}%{nginx_datadir}/luajit/share/lua

# convert to UTF-8 all files that give warnings.
for textfile in %{nginx_builddir}/CHANGES.nginx
do
    mv $textfile $textfile.old
    iconv --from-code ISO8859-1 --to-code UTF-8 --output $textfile $textfile.old
    rm -f $textfile.old
done

%clean
rm -rf %{buildroot}

%pre
if [ $1 == 1 ]; then
    %{_sbindir}/useradd -c "Nginx user" -s /bin/false -r -d %{nginx_home} %{nginx_user} 2>/dev/null || :
fi

%post
if [ $1 == 1 ]; then
    /sbin/chkconfig --add %{real_name}
fi

%preun
if [ $1 = 0 ]; then
    /sbin/service %{real_name} stop >/dev/null 2>&1
    /sbin/chkconfig --del %{real_name}
fi

%postun
if [ $1 == 2 ]; then
    /sbin/service %{real_name} upgrade || :
fi

%files
%defattr(-,root,root,-)
%doc README %{nginx_builddir}/LICENSE %{nginx_builddir}/CHANGES.nginx %{nginx_builddir}/README.nginx
%doc nginx-upstream-fair-master/README.nginx_upstream_fair
%{nginx_datadir}
%{_sbindir}/%{real_name}
%{_mandir}/man3/%{real_name}.3*
%{_mandir}/man8/%{real_name}.8*
%{_initrddir}/%{real_name}
%dir %{nginx_confdir}/
%dir %{nginx_confdir}/conf.d/
%config(noreplace) %{nginx_confdir}/conf.d/*.conf
%config(noreplace) %{nginx_confdir}/win-utf
%config(noreplace) %{nginx_confdir}/%{real_name}.conf.default
%config(noreplace) %{nginx_confdir}/mime.types.default
%config(noreplace) %{nginx_confdir}/fastcgi_params
%config(noreplace) %{nginx_confdir}/fastcgi_params.default
%config(noreplace) %{nginx_confdir}/fastcgi.conf
%config(noreplace) %{nginx_confdir}/fastcgi.conf.default
%config(noreplace) %{nginx_confdir}/uwsgi_params
%config(noreplace) %{nginx_confdir}/uwsgi_params.default
%config(noreplace) %{nginx_confdir}/scgi_params
%config(noreplace) %{nginx_confdir}/scgi_params.default
%config(noreplace) %{nginx_confdir}/koi-win
%config(noreplace) %{nginx_confdir}/koi-utf
%config(noreplace) %{nginx_confdir}/%{real_name}.conf
%config(noreplace) %{nginx_confdir}/mime.types
%config(noreplace) %{_sysconfdir}/logrotate.d/%{real_name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{real_name}
%dir %{perl_vendorarch}/auto/%{real_name}
%{perl_vendorarch}/%{real_name}.pm
%{perl_vendorarch}/auto/%{real_name}/%{real_name}.so
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home_tmp}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_logdir}


%changelog
* Wed Jun 18 2014 Denis Fateyev <denis@fateyev.com> - 1.7.0.1-1.denf
- Update to 1.7.0.1 release

* Mon Mar 10 2014 Denis Fateyev <denis@fateyev.com> - 1.5.8.1-1.denf
- Initial 1.5.8.1 release
